package com.huimv.receiver.farm.service.impl;

import com.alibaba.fastjson.JSONObject;
import com.huimv.receiver.farm.dao.entity.ProdBatchWeightEntity;
import com.huimv.receiver.farm.dao.entity.ProdDayWeightEntity;
import com.huimv.receiver.farm.dao.repo.ProdBatchWeightRepo;
import com.huimv.receiver.farm.dao.repo.ProdDayWeightRepo;
import com.huimv.receiver.farm.service.IWeight;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.sql.Timestamp;
import java.util.Date;

/**
 * @Project : huimv.shiwan
 * @Package : com.huimv.biosafety.uface.controller
 * @Description : TODO
 * @Version : 1.0
 * @Author : ZhuoNing
 * @Create : 2020-12-25
 **/
@Service
public class WeightImpl implements IWeight {
    @Autowired
    private ProdDayWeightRepo dayWeightRepo;
    @Autowired
    private ProdBatchWeightRepo batchWeightRepo;

    /**
     * @Method      : saveDayWeight
     * @Description : 保存日总重数据
     * @Params      : [data]
     * @Return      : void
     * 
     * @Author      : ZhuoNing
     * @Date        : 2021/12/7       
     * @Time        : 19:48
     */
    @Override
    public void saveDayWeight(String data) {
        JSONObject dayWeightJo = JSONObject.parseObject(data);
        Long date = dayWeightJo.getLong("addTime");
        Integer farmId = dayWeightJo.getInteger("farmId");
        //
        ProdDayWeightEntity existDayWeightEntity = dayWeightRepo.findByDateAndFarmId(new Date(date),farmId);
        if(existDayWeightEntity != null){
            existDayWeightEntity.setAddTime(new Timestamp(new Date().getTime()));
            existDayWeightEntity.setGrossWeight(dayWeightJo.getFloat("grossWeight"));
            existDayWeightEntity.setTareWeight(dayWeightJo.getFloat("tareWeight"));
            existDayWeightEntity.setNetWeight(dayWeightJo.getFloat("netWeight"));
            dayWeightRepo.saveAndFlush(existDayWeightEntity);
        }else{
            ProdDayWeightEntity newDayWeightEntity = new ProdDayWeightEntity();
            newDayWeightEntity.setAddTime(new Timestamp(new Date().getTime()));
            newDayWeightEntity.setFarmId(dayWeightJo.getInteger("farmId"));
            newDayWeightEntity.setGrossWeight(dayWeightJo.getFloat("grossWeight"));
            newDayWeightEntity.setTareWeight(dayWeightJo.getFloat("tareWeight"));
            newDayWeightEntity.setNetWeight(dayWeightJo.getFloat("netWeight"));
            dayWeightRepo.saveAndFlush(newDayWeightEntity);
        }

    }

    /**
     * @Method      : saveBatchWeight
     * @Description : 保存批次重量数据
     * @Params      : [data]
     * @Return      : void
     * 
     * @Author      : ZhuoNing
     * @Date        : 2021/12/7       
     * @Time        : 19:49
     */
    @Override
    public void saveBatchWeight(String data) {
        JSONObject batchWeightJo = JSONObject.parseObject(data);
        String batchCode = batchWeightJo.getString("batchCode");
        System.out.println("batchCode<<"+batchCode);
        //查找批次称重数据
        ProdBatchWeightEntity existBatchWeightEntity = batchWeightRepo.findByBatchCode(batchCode);
        if(existBatchWeightEntity == null){
            ProdBatchWeightEntity newBatchWeightEntity = new ProdBatchWeightEntity();
            newBatchWeightEntity.setBatchCode(batchWeightJo.getString("batchCode"));
            newBatchWeightEntity.setBatchSort(batchWeightJo.getInteger("batchSort"));
            newBatchWeightEntity.setFarmId(batchWeightJo.getInteger("farmId"));
            newBatchWeightEntity.setGrossWeight(batchWeightJo.getFloat("grossWeight"));
            newBatchWeightEntity.setTareWeight(batchWeightJo.getFloat("tareWeight"));
            newBatchWeightEntity.setNetWeight(batchWeightJo.getFloat("netWeight"));
            newBatchWeightEntity.setAddTime(new Timestamp(new Date().getTime()));
            batchWeightRepo.saveAndFlush(newBatchWeightEntity);
        }else{
            existBatchWeightEntity.setGrossWeight(batchWeightJo.getFloat("grossWeight"));
            existBatchWeightEntity.setTareWeight(batchWeightJo.getFloat("tareWeight"));
            existBatchWeightEntity.setNetWeight(batchWeightJo.getFloat("netWeight"));
            batchWeightRepo.saveAndFlush(existBatchWeightEntity);
        }
    }
}
